@@ -1,20 +1,21 @@
-// Hello, World! application. Copyright (C) 1996-1998 Santa Fe Institute.
+// Hello, World! application. Copyright (C) 1996-1999 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <swarmobject/SwarmObject.h>
+#import <objectbase/SwarmObject.h>
 
 // This is just a sample agent: real models need real agents.
 
-@interface Counter: SwarmObject {
+@interface Counter: SwarmObject
+{
   int value;
   int incr;
 }
 
--step;
--setIncr: (int) n;
--print;
+- step;
+- setIncr: (int) n;
+- print;
 
 @end
 
