@@ -1,4 +1,4 @@
-// Market application. Copyright (C) 1996-1998 Santa Fe Institute.
+// Market application. Copyright (C) 1996-1999 Santa Fe Institute.
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
@@ -19,7 +19,7 @@ main (int argc, const char **argv)
 {
   MarketObserverSwarm *observerSwarm;
   
-  initSwarm (argc, argv);
+  initSwarmApp (argc, argv, "1.4.1", "bug-swarm@santafe.edu");
 
   observerSwarm = [MarketObserverSwarm createBegin: globalZone];
   SET_WINDOW_GEOMETRY_RECORD_NAME (observerSwarm);
